Computational photography (photo module) {#tutorial_table_of_content_photo}
========================================

Use OpenCV for advanced photo processing.

-   @subpage tutorial_hdr_imaging

    *Languages:* C++, Java, Python

    *Compatibility:* \> OpenCV 3.0

    *Author:* Fedor Morozov

    Learn how to create and process high dynamic range images.
